======================
simple pastebin parser
======================




.. image:: https://pyup.io/repos/github/shlomikushchi/simple_pastebin_parser/shield.svg
     :target: https://pyup.io/repos/github/shlomikushchi/simple_pastebin_parser/
     :alt: Updates



a small web crawler for the pastebin.com website



Features
--------

* TODO
